@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2018,2020 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -39,20 +39,27 @@
 /**                for the symbolic factorization routine. **/
 /**                                                        **/
 /**   DATES      : # Version 0.0  : from : 22 jul 1998     **/
-/**                                 to     24 sep 1998     **/
+/**                                 to   : 24 sep 1998     **/
 /**                # Version 0.1  : from : 04 apr 1999     **/
-/**                                 to     01 may 1999     **/
+/**                                 to   : 01 may 1999     **/
 /**                # Version 6.0  : from : 22 may 2018     **/
-/**                                 to     22 may 2018     **/
+/**                                 to   : 22 may 2018     **/
+/**                # Version 6.1  : from : 22 feb 2020     **/
+/**                                 to   : 22 feb 2020     **/
 /**                                                        **/
 /************************************************************/
 
 #define ESMUMPS_H
 
+#ifndef ESMUMPS_HAS_ESMUMPSV
+#define ESMUMPS_HAS_ESMUMPSV
+#endif /* ESMUMPS_HAS_ESMUMPSV */
+
 /*
 **  The function prototypes.
 */
 
 int                         esmumps             (const INT n, const INT iwlen, INT * const pe, const INT pfree, INT * const len, INT * const iw, INT * const nv, INT * const elen, INT * const last);
+int                         esmumpsv            (const INT n, const INT iwlen, INT * const pe, const INT pfree, INT * const len, INT * const iw, INT * const nv, INT * const elen, INT * const last);
 
 int                         esmumps_strat1      (const INT procnbr, const INT leafsiz, const int leorval, const INT cminval, const INT cmaxval, const double fratval, const int verbval, FILE * const stream, char * const straptr);
