@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -39,9 +39,11 @@
 /**                for the ESMUMPS library module.         **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 22 jan 2009     **/
-/**                                 to     22 jan 2009     **/
+/**                                 to   : 22 jan 2009     **/
 /**                # Version 6.0  : from : 21 may 2018     **/
-/**                                 to     21 may 2018     **/
+/**                                 to   : 21 may 2018     **/
+/**                # Version 6.0  : from : 21 may 2018     **/
+/**                                 to   : 21 may 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -181,6 +183,7 @@
 #define symbolDrawColor             ESMUMPS_NAME_INTERN (symbolDrawColor)
 #define symbolDrawFunc              ESMUMPS_NAME_INTERN (symbolDrawFunc)
 #define symbolExit                  ESMUMPS_NAME_INTERN (symbolExit)
+#define symbolFaxGraph              ESMUMPS_NAME_INTERN (symbolFaxGraph)
 #define symbolInit                  ESMUMPS_NAME_INTERN (symbolInit)
 #define symbolLevf                  ESMUMPS_NAME_INTERN (symbolLevf)
 #define symbolLoad                  ESMUMPS_NAME_INTERN (symbolLoad)
