@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -43,6 +43,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 16 nov 2007     **/
 /**                                 to   : 19 jul 2011     **/
+/**                # Version 6.0  : from : 11 sep 2011     **/
+/**                                 to   : 31 aug 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -59,13 +61,6 @@
 #include "bdgraph.h"
 #include "bdgraph_bipart_df.h"
 
-/*
-**  The static variables.
-*/
-
-static const Gnum           bdgraphbipartdfloadone  = 1;
-static const Gnum           bdgraphbipartdfloadzero = 0;
-
 /*****************************/
 /*                           */
 /* This is the main routine. */
@@ -86,7 +81,7 @@ Bdgraph * const                     grafptr,      /*+ Distributed graph +*/
 const BdgraphBipartDfParam * const  paraptr)      /*+ Method parameters +*/
 {
   float * restrict        ielsloctax;             /* Inverse of degree array   */
-  float * restrict        veexloctax;             /* Veexval over domdist      */
+  float * restrict        veexloctax;             /* Veexval over domndist     */
   float * restrict        difogsttax;             /* Old diffusion value array */
   float * restrict        difngsttax;             /* New diffusion value array */
   const Gnum * restrict   edgegsttax;
@@ -96,10 +91,6 @@ const BdgraphBipartDfParam * const  paraptr)      /*+ Method parameters +*/
   float                   valolocval[2];          /* Fraction of load to remove from anchor vertices at each step */
   Gnum                    vanclocnnd;
   Gnum                    vertlocnum;
-  const Gnum * restrict   velolocbax;
-  Gnum                    velolocmsk;
-  const Gnum * restrict   edlolocbax;
-  Gnum                    edlolocmsk;
   Gnum                    complocload1;
   Gnum                    complocsize1;
   Gnum                    commlocloadintn;
@@ -112,6 +103,9 @@ const BdgraphBipartDfParam * const  paraptr)      /*+ Method parameters +*/
   float                   cremval;
   int                     ovflval;                /* Overflow flag value */
 
+  const Gnum * restrict const veloloctax = grafptr->s.veloloctax;
+  const Gnum * restrict const edloloctax = grafptr->s.edloloctax;
+
   if (dgraphGhst (&grafptr->s) != 0) {            /* Compute ghost edge array if not already present */
     errorPrint ("bdgraphBipartDf: cannot compute ghost edge array");
     return     (1);
@@ -318,23 +312,6 @@ abort :                                           /* If overflow occured, resume
   grafptr->partgsttax[vanclocnnd]     = 0;        /* Set up parts in case anchors are isolated */
   grafptr->partgsttax[vanclocnnd + 1] = 1;
 
-  if (grafptr->s.veloloctax != NULL) {
-    velolocbax = grafptr->s.veloloctax;
-    velolocmsk = ~((Gnum) 0);
-  }
-  else {
-    velolocbax = &bdgraphbipartdfloadone;
-    velolocmsk = 0;
-  }
-  if (grafptr->s.edloloctax != NULL) {
-    edlolocbax = grafptr->s.edloloctax;
-    edlolocmsk = ~((Gnum) 0);
-  }
-  else {
-    edlolocbax = &bdgraphbipartdfloadone;
-    edlolocmsk = 0;
-  }
-
   memFree (ielsloctax + grafptr->s.baseval);      /* Free group leader */
 
   if (dgraphHaloSync (&grafptr->s, (byte *) (void *) (grafptr->partgsttax + grafptr->s.baseval), GRAPHPART_MPI) != 0) {
@@ -360,7 +337,7 @@ abort :                                           /* If overflow occured, resume
     }
 #endif /* SCOTCH_DEBUG_BDGRAPH2 */
     partval = (Gnum) grafptr->partgsttax[vertlocnum];
-    veloval = velolocbax[vertlocnum & velolocmsk];
+    veloval = (veloloctax != NULL) ? veloloctax[vertlocnum] : 1;
     if (grafptr->veexloctax != NULL) {
       commlocloadextn += grafptr->veexloctax[vertlocnum] * partval;
       commlocgainextn += grafptr->veexloctax[vertlocnum] * (1 - partval * 2);
@@ -382,7 +359,7 @@ abort :                                           /* If overflow occured, resume
         break;                                    /* Do not break upcoming collective communications */
       }
 #endif /* SCOTCH_DEBUG_BDGRAPH2 */
-      edloval  = edlolocbax[edgelocnum & edlolocmsk];
+      edloval  = (edloloctax != NULL) ? edloloctax[edgelocnum] : 1;
       flagval |= partval ^ partend;
       commlocloadintn += (partval ^ partend) * edloval; /* Internal load is accounted for twice */
     }
@@ -407,8 +384,9 @@ abort :                                           /* If overflow occured, resume
   grafptr->compglbload0    = reduglbtab[1];
   grafptr->compglbload0dlt = grafptr->compglbload0 - grafptr->compglbload0avg;
   grafptr->compglbsize0    = reduglbtab[2];
-  grafptr->commglbload     = (reduglbtab[3] / 2) * grafptr->domdist + reduglbtab[4];
+  grafptr->commglbload     = (reduglbtab[3] / 2) * grafptr->domndist + reduglbtab[4];
   grafptr->commglbgainextn = reduglbtab[5];
+  grafptr->bbalglbval      = (double) ((grafptr->compglbload0dlt < 0) ? (- grafptr->compglbload0dlt) : grafptr->compglbload0dlt) / (double) grafptr->compglbload0avg;
 
 #ifdef SCOTCH_DEBUG_BDGRAPH2
   if (bdgraphCheck (grafptr) != 0) {
