@@ -1,4 +1,4 @@
-/* Copyright 2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2008,2013 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -39,7 +39,9 @@
 /**   FUNCTION   : This module handles (partial) mappings. **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 31 mar 2008     **/
-/**                                 to     09 nov 2008     **/
+/**                                 to   : 09 nov 2008     **/
+/**                # Version 6.0  : from : 03 sep 2013     **/
+/**                                 to   : 03 sep 2013     **/
 /**                                                        **/
 /************************************************************/
 
@@ -235,11 +237,11 @@ Gnum * restrict const           termloctab)
 
   for (vertlocnum = 0, procnum = 0; procnum < grafptr->procglbnbr; ) {
     Gnum                  vertsndnbr;
-    Gnum                  procdspval;
+    Gnum                  procvrtval;
 
     vertsndnbr = 0;
-    procdspval = grafptr->procdsptab[procnum + 1];
-    while (sortsndtab[vertlocnum].vertnum < procdspval) {
+    procvrtval = grafptr->procvrttab[procnum + 1];
+    while (sortsndtab[vertlocnum].vertnum < procvrtval) {
       vertsndnbr ++;
       vertlocnum ++;
 #ifdef SCOTCH_DEBUG_DMAP2
@@ -277,7 +279,7 @@ Gnum * restrict const           termloctab)
 
   memSet (termloctab, ~0, grafptr->vertlocnbr * sizeof (Gnum));
 
-  termloctax = termloctab - grafptr->procdsptab[grafptr->proclocnum]; /* Base local array through global indices */
+  termloctax = termloctab - grafptr->procvrttab[grafptr->proclocnum]; /* Base local array through global indices */
   for (vertlocnum = 0; vertlocnum < grafptr->vertlocnbr; vertlocnum ++) {
 #ifdef SCOTCH_DEBUG_DMAP2
     if (termloctax[sortrcvtab[vertlocnum].vertnum] != ~0) {
