@@ -1,4 +1,4 @@
-/* Copyright 2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2008,2010,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -34,13 +34,15 @@
 /**   NAME       : dmapping.h                              **/
 /**                                                        **/
 /**   AUTHORS    : Francois PELLEGRINI                     **/
-/**                Jun-Ho HER                              **/
+/**                Jun-Ho HER (v6.0)                       **/
 /**                                                        **/
 /**   FUNCTION   : These lines are the declarations for    **/
 /**                the parallel mapping handling routines. **/
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 31 mar 2008     **/
-/**                                 to     04 nov 2010     **/
+/**                                 to   : 04 nov 2010     **/
+/**                # Version 6.0  : from : 07 jun 2018     **/
+/**                                 to   : 07 jun 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -89,14 +91,8 @@ typedef struct DmappingTermSort_ {
 **  The function prototypes.
 */
 
-#ifndef DMAPPING
-#define static
-#endif
-
 int                         dmapInit            (Dmapping * restrict const, const Arch * restrict const);
 void                        dmapExit            (Dmapping * const);
 void                        dmapAdd             (Dmapping * restrict const, DmappingFrag * restrict const);
 int                         dmapSave            (const Dmapping * restrict const, const Dgraph * restrict const, FILE * restrict const);
 int                         dmapTerm            (const Dmapping * restrict const, const Dgraph * restrict const, Gnum * restrict const);
-
-#undef static
