@@ -1,4 +1,4 @@
-/* Copyright 2007,2010,2012 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2010,2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -45,7 +45,7 @@
 /**                # Version 5.1  : from : 30 jul 2010     **/
 /**                                 to   : 30 jul 2010     **/
 /**                # Version 6.0  : from : 27 nov 2012     **/
-/**                                 to     27 nov 2012     **/
+/**                                 to   : 23 may 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -181,7 +181,7 @@ Hgraph * restrict const     cgrfptr)              /* Centralized halo graph */
       cgrfptr->vnohnnd   = vnohnbr + dgrfptr->s.baseval;
       cgrfptr->vnlosum   = dgrfptr->s.veloglbsum;
       cgrfptr->enohnbr   =
-      cgrfptr->enohsum   = dgrfptr->s.edgeglbnbr;
+      cgrfptr->enlosum   = dgrfptr->s.edgeglbnbr;
       cgrfptr->levlnum   = dgrfptr->levlnum;
     }
   }
