@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2012,2014,2016,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -39,9 +39,11 @@
 /**                functions.                              **/
 /**                                                        **/
 /**   DATES      : # Version 4.0  : from : 17 jan 2002     **/
-/**                                 to     01 dec 2003     **/
+/**                                 to   : 01 dec 2003     **/
 /**                # Version 5.0  : from : 19 dec 2006     **/
-/**                                 to     30 may 2008     **/
+/**                                 to   : 30 may 2008     **/
+/**                # Version 6.0  : from : 17 oct 2012     **/
+/**                                 to   : 23 may 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -99,10 +101,9 @@ void
 hgraphFree (
 Hgraph * restrict const     grafptr)
 {
-  if ((grafptr->vnhdtax != NULL)               && /* Free end vertex array for non-halo vertices */
-      (grafptr->vnhdtax != grafptr->s.vendtax) &&
+  if ((grafptr->vnhdtax != NULL) &&               /* Free end vertex array for non-halo vertices */
       ((grafptr->s.flagval & HGRAPHFREEVNHD) != 0))
-    memFree (grafptr->vnhdtax);
+    memFree (grafptr->vnhdtax + grafptr->s.baseval);
 
   graphFree (&grafptr->s);                        /* Free graph data */
 
@@ -110,3 +111,32 @@ Hgraph * restrict const     grafptr)
   memSet (grafptr, ~0, sizeof (Hgraph));          /* Purge graph fields */
 #endif /* SCOTCH_DEBUG_HGRAPH2 */
 }
+
+/* This routine creates a non-halo graph from a
+** halo graph.
+** It returns:
+** - VOID  : in all cases.
+*/
+
+void
+hgraphUnhalo (
+const Hgraph * restrict const grafptr,
+Graph * restrict const        ugrfptr)
+{
+  ugrfptr->flagval = grafptr->s.flagval & (GRAPHBITSUSED & ~GRAPHFREETABS); /* Remove extended graph class flags and do not allow freeing */
+  ugrfptr->baseval = grafptr->s.baseval;
+  ugrfptr->vertnbr = grafptr->vnohnbr;
+  ugrfptr->vertnnd = grafptr->vnohnnd;
+  ugrfptr->verttax = grafptr->s.verttax;
+  ugrfptr->vendtax = grafptr->vnhdtax;
+  ugrfptr->velotax = grafptr->s.velotax;
+  ugrfptr->velosum = grafptr->vnlosum;
+  ugrfptr->vnumtax = grafptr->s.vnumtax;
+  ugrfptr->vlbltax = NULL;
+  ugrfptr->edgenbr = grafptr->enohnbr;
+  ugrfptr->edgetax = grafptr->s.edgetax;
+  ugrfptr->edlotax = grafptr->s.edlotax;
+  ugrfptr->edlosum = grafptr->enlosum;
+  ugrfptr->degrmax = grafptr->s.degrmax;          /* Upper bound */
+  ugrfptr->procptr = grafptr->s.procptr;
+}
