@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2010,2012,2014,2016,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -41,13 +41,15 @@
 /**   DATES      : # Version 3.2  : from : 17 oct 1996     **/
 /**                                 to   : 21 aug 1998     **/
 /**                # Version 3.3  : from : 02 oct 1998     **/
-/**                                 to     13 mar 1999     **/
+/**                                 to   : 13 mar 1999     **/
 /**                # Version 4.0  : from : 03 jan 2002     **/
-/**                                 to     24 dec 2004     **/
+/**                                 to   : 24 dec 2004     **/
 /**                # Version 5.0  : from : 19 dec 2006     **/
-/**                                 to     25 jul 2007     **/
+/**                                 to   : 25 jul 2007     **/
 /**                # Version 5.1  : from : 24 oct 2010     **/
-/**                                 to     24 oct 2010     **/
+/**                                 to   : 24 oct 2010     **/
+/**                # Version 6.0  : from : 17 oct 2012     **/
+/**                                 to   : 23 may 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -95,21 +97,7 @@ const HgraphOrderNdParam * restrict const paraptr)
   Gnum                      vspvertnum;           /* Current vertex in separation graph */
   int                       o;
 
-  vspgrafdat.s.flagval = GRAPHNONE;               /* Do not free contents of separation graph   */
-  vspgrafdat.s.baseval = grafptr->s.baseval;
-  vspgrafdat.s.vertnbr = grafptr->vnohnbr;        /* Keep only non-halo vertices for separation */
-  vspgrafdat.s.vertnnd = grafptr->vnohnnd;
-  vspgrafdat.s.verttax = grafptr->s.verttax;
-  vspgrafdat.s.vendtax = grafptr->vnhdtax;
-  vspgrafdat.s.velotax = grafptr->s.velotax;
-  vspgrafdat.s.velosum = grafptr->vnlosum;
-  vspgrafdat.s.vnumtax = grafptr->s.vnumtax;
-  vspgrafdat.s.vlbltax = NULL;
-  vspgrafdat.s.edgenbr = grafptr->enohnbr;
-  vspgrafdat.s.edgetax = grafptr->s.edgetax;
-  vspgrafdat.s.edlotax = grafptr->s.edlotax;
-  vspgrafdat.s.edlosum = grafptr->enohsum;
-  vspgrafdat.s.degrmax = grafptr->s.degrmax;
+  hgraphUnhalo (grafptr, &vspgrafdat.s);          /* Keep only non-halo vertices for separation */
 
   if ((vspgrafdat.frontab = (Gnum *) memAlloc (vspgrafdat.s.vertnbr * sizeof (Gnum))) == NULL) {
     errorPrint ("hgraphOrderNd: out of memory (1)");
@@ -122,7 +110,6 @@ const HgraphOrderNdParam * restrict const paraptr)
   }
   memSet (vspgrafdat.parttax, 0, vspgrafdat.s.vertnbr * sizeof (GraphPart)); /* Set all vertices to part 0 */
   vspgrafdat.parttax    -= vspgrafdat.s.baseval;
-  vspgrafdat.fronnbr     = 0;
   vspgrafdat.compload[0] = vspgrafdat.s.velosum;
   vspgrafdat.compload[1] = 0;
   vspgrafdat.compload[2] = 0;
@@ -212,7 +199,7 @@ const HgraphOrderNdParam * restrict const paraptr)
     cblkptr->cblktab[2].cblknbr = 0;
     cblkptr->cblktab[2].cblktab = NULL;
 
-    if (graphInduceList (&grafptr->s, &vsplisttab[2], &indgrafdat.s) != 0) { /* Perform non-halo induction for separator, as it will get highest numbers */
+    if (graphInduceList (&grafptr->s, vsplisttab[2].vnumnbr, vsplisttab[2].vnumtab, &indgrafdat.s) != 0) { /* Perform non-halo induction for separator, as it will get highest numbers */
       errorPrint ("hgraphOrderNd: cannot build induced subgraph (1)");
       memFree    (vspgrafdat.frontab);            /* Free remaining space */
       return     (1);
@@ -222,7 +209,7 @@ const HgraphOrderNdParam * restrict const paraptr)
     indgrafdat.vnhdtax = indgrafdat.s.vendtax;
     indgrafdat.vnlosum = indgrafdat.s.velosum;
     indgrafdat.enohnbr = indgrafdat.s.edgenbr;
-    indgrafdat.enohsum = indgrafdat.s.edlosum;
+    indgrafdat.enlosum = indgrafdat.s.edlosum;
     indgrafdat.levlnum = grafptr->levlnum;        /* Separator graph is at level of original graph */
 
     o = hgraphOrderSt (&indgrafdat, ordeptr, ordenum + vsplisttab[0].vnumnbr + vsplisttab[1].vnumnbr,
@@ -236,7 +223,7 @@ const HgraphOrderNdParam * restrict const paraptr)
     o = 0;                                        /* No separator ordering computed */
   }
   if (o == 0) {
-    if ((hgraphInduceList (grafptr, &vsplisttab[0], vsplisttab[2].vnumnbr + grafptr->s.vertnbr - grafptr->vnohnbr, &indgrafdat)) != 0) {
+    if ((hgraphInduceList (grafptr, vsplisttab[0].vnumnbr, vsplisttab[0].vnumtab, vsplisttab[2].vnumnbr + grafptr->s.vertnbr - grafptr->vnohnbr, &indgrafdat)) != 0) {
       errorPrint ("hgraphOrderNd: cannot build induced subgraph (2)");
       memFree    (vspgrafdat.frontab);            /* Free remaining space */
       return     (1);
@@ -245,7 +232,7 @@ const HgraphOrderNdParam * restrict const paraptr)
     hgraphExit (&indgrafdat);
   }
   if (o == 0) {
-    if ((hgraphInduceList (grafptr, &vsplisttab[1], vsplisttab[2].vnumnbr + grafptr->s.vertnbr - grafptr->vnohnbr, &indgrafdat)) != 0) {
+    if ((hgraphInduceList (grafptr, vsplisttab[1].vnumnbr, vsplisttab[1].vnumtab, vsplisttab[2].vnumnbr + grafptr->s.vertnbr - grafptr->vnohnbr, &indgrafdat)) != 0) {
       errorPrint ("hgraphOrderNd: cannot build induced subgraph (3)");
       memFree    (vspgrafdat.frontab);            /* Free remaining space */
       return     (1);
