@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -40,9 +40,9 @@
 /**                functions.                              **/
 /**                                                        **/
 /**   DATES      : # Version 4.0  : from : 26 jan 2003     **/
-/**                                 to     11 may 2004     **/
+/**                                 to   : 11 may 2004     **/
 /**                # Version 5.0  : from : 12 sep 2007     **/
-/**                                 to     12 sep 2007     **/
+/**                                 to   : 03 apr 2008     **/
 /**                                                        **/
 /**   NOTES      : # This routine differs from the         **/
 /**                  standard mesh induction routine by    **/
@@ -136,7 +136,7 @@ Mesh * restrict const             indmeshptr)     /* Pointer to induced submesh
   Gnum                          hashmsk;          /* Mask for hash array                                        */
   void * restrict               p;
 
-  orgbitssiz = (orgmeshptr->velmnbr + (INT_BITS - 1)) / INT_BITS; /* Compute size of element bit array */
+  orgbitssiz = (orgmeshptr->velmnbr + (INTSIZEBITS - 1)) / INTSIZEBITS; /* Compute size of element bit array */
   if ((orgbitstab = (unsigned int *) memAlloc (orgbitssiz * sizeof (unsigned int))) == NULL) {
     errorPrint ("meshInduceSepa: out of memory (1)");
     return     (1);
@@ -156,8 +156,8 @@ Mesh * restrict const             indmeshptr)     /* Pointer to induced submesh
       Gnum                orgvelmbit;             /* Bit to update in element bit array     */
 
       orgvelmidx  = orgmeshptr->edgetax[orgenodnum] - orgmeshptr->velmbas;
-      orgvelmbit  = orgvelmidx & (INT_BITS - 1);
-      orgvelmidx /= INT_BITS;
+      orgvelmbit  = orgvelmidx & (INTSIZEBITS - 1);
+      orgvelmidx /= INTSIZEBITS;
       indvelmnbr += (orgbitstab[orgvelmidx] >> orgvelmbit) & 1; /* Count element vertex if not yet accounted for */
       orgbitstab[orgvelmidx] &= ~(1 << orgvelmbit);
     }
@@ -267,7 +267,7 @@ Mesh * restrict const             indmeshptr)     /* Pointer to induced submesh
 
             indedgetax[indedgenum ++] = orgindxtax[orgvnodend]; /* Add node to element edge sub-array */
 
-            for (hashnum = (orgindxtax[orgvnodend] * MESHINDUCESEPAHASHPRIME) & hashmsk; 
+            for (hashnum = (orgindxtax[orgvnodend] * MESHINDUCESEPAHASHPRIME) & hashmsk;
                  hashtab[hashnum].orgvelmnum == orgvelmnum; hashnum = (hashnum + 1) & hashmsk) ;
             hashtab[hashnum].orgvelmnum = orgvelmnum; /* Add vertex to hash table */
             hashtab[hashnum].indvnodnum = orgindxtax[orgvnodend];
