@@ -1,4 +1,4 @@
-/* Copyright 2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -40,9 +40,11 @@
 /**                ration strategy and method tables.      **/
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 16 feb 2006     **/
-/**                                 to     08 mar 2006     **/
+/**                                 to   : 08 mar 2006     **/
 /**                # Version 5.1  : from : 05 nov 2007     **/
-/**                                 to     05 nov 2007     **/
+/**                                 to   : 05 nov 2007     **/
+/**                # Version 6.0  : from : 06 jun 2018     **/
+/**                                 to   : 06 jun 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -71,10 +73,4 @@ extern StratTab             vdgraphseparateststratab;
 **  The function prototypes.
 */
 
-#ifndef VDGRAPH_SEPARATE_ST
-#define static
-#endif
-
 int                         vdgraphSeparateSt   (Vdgraph * const, const Strat * const);
-
-#undef static
