@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -45,6 +45,8 @@
 /**                                 to   : 12 sep 2007     **/
 /**                # Version 5.1  : from : 30 oct 2007     **/
 /**                                 to   : 09 nov 2008     **/
+/**                # Version 6.0  : from : 31 may 2018     **/
+/**                                 to   : 31 may 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -94,6 +96,7 @@ const VgraphSeparateBdParam * const paraptr)      /*+ Method parameters +*/
   Gnum                        bndedgetmp;
   Gnum                        bnddegrmax;
   Gnum                        fronnum;
+
   const Gnum * restrict const orgverttax = orggrafptr->s.verttax; /* Fast accesses */
   const Gnum * restrict const orgvendtax = orggrafptr->s.vendtax;
   const Gnum * restrict const orgvelotax = orggrafptr->s.velotax;
@@ -176,7 +179,6 @@ const VgraphSeparateBdParam * const paraptr)      /*+ Method parameters +*/
 
       orgvertend = orgedgetax[orgedgenum];
       if (orgdisttax[orgvertend] == ~0) {         /* If vertex not visited yet */
-
 #ifdef SCOTCH_DEBUG_VGRAPH2
         if (orggrafptr->parttax[orgvertend] > 1) {
           errorPrint ("vgraphSeparateBd: internal error (5)");
@@ -334,12 +336,9 @@ const VgraphSeparateBdParam * const paraptr)      /*+ Method parameters +*/
   }
 #endif /* SCOTCH_DEBUG_VGRAPH2 */
   bndgrafdat.s.edgenbr =
-  bndgrafdat.s.edlosum = bndedgetmp - orggrafptr->s.baseval; /* Since edge load array not kept       */
-  bndgrafdat.s.verttax[bndvertnnd + 2] = bndedgetmp; /* Mark end of edge array with anchor vertices  */
-  for (bndvertnum = bndvlvlnum; bndvertnum < bndvertnnd; bndvertnum ++) { /* Fill anchor edge arrays */
-    Gnum                orgvertnum;
-
-    orgvertnum = bndvnumtax[bndvertnum];
+  bndgrafdat.s.edlosum = bndedgetmp - orggrafptr->s.baseval; /* Since edge load array not kept                  */
+  bndgrafdat.s.verttax[bndvertnnd + 2] = bndedgetmp; /* Mark end of edge array with anchor vertices             */
+  for (bndvertnum = bndvlvlnum; bndvertnum < bndvertnnd; bndvertnum ++) { /* Fill anchor edge arrays            */
     if (bndgrafdat.s.verttax[bndvertnum + 1] > bndgrafdat.s.verttax[bndvertnum]) { /* If vertex is not isolated */
       Gnum                bndvertend;
 
