@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -41,11 +41,11 @@
 /**                heuristics.                             **/
 /**                                                        **/
 /**   DATES      : # Version 4.0  : from : 26 feb 2003     **/
-/**                                 to     06 may 2004     **/
+/**                                 to   : 06 may 2004     **/
 /**                # Version 5.0  : from : 12 sep 2007     **/
-/**                                 to     22 may 2008     **/
+/**                                 to   : 22 may 2008     **/
 /**                # Version 5.1  : from : 12 nov 2008     **/
-/**                                 to     12 nov 2008     **/
+/**                                 to   : 12 nov 2008     **/
 /**                                                        **/
 /************************************************************/
 
@@ -377,7 +377,7 @@ const VmeshSeparateFmParam * restrict const paraptr) /*+ Method parameters    +*
   ncmpload2      = meshptr->ncmpload[2];          /* Set current partition loads    */
   ncmploaddlt    = meshptr->ncmploaddlt;
 
-  memset (helmtab, ~0, (byte *) &hnodtab[hashsiz] - (byte *) helmtab); /* Set all vertex numbers to ~0 */
+  memSet (helmtab, ~0, (byte *) &hnodtab[hashsiz] - (byte *) helmtab); /* Set all vertex numbers to ~0 */
 
   helmnbr =
   hnodnbr = 0;
@@ -931,7 +931,7 @@ const VmeshSeparateFmParam * restrict const paraptr) /*+ Method parameters    +*
 
     while (savenbr > 0) {                         /* Delete exceeding moves */
       Gnum                hertnum;
-      
+     
       hertnum = movetab[-- savenbr].hertnum;      /* Get vertex hash number */
       if (hertnum >= 0) {                         /* If vertex is element   */
         helmtab[hertnum].vertpart    = movetab[savenbr].data.elem.vertpart;
