@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -41,7 +41,7 @@
 /**                sive bipartitioning approach.           **/
 /**                                                        **/
 /**   DATES      : # Version 6.0  : from : 16 mar 2010     **/
-/**                                 to     26 feb 2018     **/
+/**                                 to   : 26 feb 2018     **/
 /**                                                        **/
 /**   NOTES      : # This code derives from the code of    **/
 /**                  kgraph_map_rb_part.c for the vertex   **/
@@ -83,7 +83,7 @@ static const Gnum           wgraphpartrbloadone = 1;
 /*                                          */
 /********************************************/
 
-/* This routine runs recursive 
+/* This routine runs recursive
 ** bipartitioning approach.
 ** It returns:
 ** - 0   : on success.
@@ -268,9 +268,9 @@ const WgraphPartRbParam * restrict const  paraptr)
     errorPrint ("wgraphPartRb: out of memory (1)");
     return     (1);
   }
-  listtab ++;                                     /* TRICK: Trim array so that listtab[-1] is valid */
+  listtab ++;                                     /* TRICK: trim array so that listtab[-1] is valid */
   memSet (listtab, ~0, grafptr->partnbr * sizeof (WgraphPartList)); /* Set vertex indices to ~0     */
-  
+ 
   datadat.grafptr  = &grafptr->s;
   datadat.frontab  = grafptr->frontab;            /* Re-use frontier array */
   datadat.fronnbr  = 0;
