@@ -19,13 +19,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -36,7 +36,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -52,11 +52,11 @@
 /**                the Scotch project.                     **/
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 08 sep 2006     **/
-/**                                 to     07 jun 2007     **/
+/**                                 to   : 07 jun 2007     **/
 /**                # Version 5.1  : from : 30 jun 2010     **/
-/**                                 to     30 jun 2010     **/
+/**                                 to   : 30 jun 2010     **/
 /**                # Version 6.0  : from : 13 sep 2012     **/
-/**                                 to     18 may 2019     **/
+/**                                 to   : 17 jun 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -85,6 +85,12 @@
 #define METISNAME4(p,s)             p##s
 #endif /* METISNAMEL */
 
+#ifndef SCOTCH_METIS_DATATYPES
+#define SCOTCH_METIS_DATATYPES
+typedef SCOTCH_Num          idx_t;
+typedef double              real_t;
+#endif /* SCOTCH_METIS_DATATYPES */
+
 #ifndef SCOTCH_METIS_RETURN
 #define SCOTCH_METIS_RETURN
 typedef enum {
@@ -92,7 +98,7 @@ typedef enum {
   METIS_ERROR_INPUT  = -2,
   METIS_ERROR_MEMORY = -3,
   METIS_ERROR        = -4
-} rstatus_et; 
+} rstatus_et;
 #endif /* SCOTCH_METIS_RETURN */
 
 /*
