@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -41,11 +41,11 @@
 /**                routines.                               **/
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 08 sep 2006     **/
-/**                                 to     07 jun 2007     **/
+/**                                 to   : 07 jun 2007     **/
 /**                # Version 5.1  : from : 06 jun 2009     **/
-/**                                 to     30 jun 2010     **/
+/**                                 to   : 30 jun 2010     **/
 /**                # Version 6.0  : from : 23 dec 2011     **/
-/**                                 to     18 may 2019     **/
+/**                                 to   : 19 aug 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -248,7 +248,7 @@ const double * const        kbalval)
   SCOTCH_Num                  edgenum;
   const SCOTCH_Num * restrict edgetax;
   const SCOTCH_Num * restrict parttax;
-  SCOTCH_Num * restrict       nghbtab;
+  SCOTCH_Num * restrict       nghbtax;
   SCOTCH_Num                  commvol;
 
   baseval = *numflag;
@@ -294,9 +294,10 @@ const double * const        kbalval)
       return (METIS_ERROR);
   }
 
-  if ((nghbtab = memAlloc (*nparts * sizeof (SCOTCH_Num))) == NULL)
+  if ((nghbtax = memAlloc (*nparts * sizeof (SCOTCH_Num))) == NULL) /* Part array is un-based at allocation */
     return (METIS_ERROR_MEMORY);
-  memSet (nghbtab, ~0, *nparts * sizeof (SCOTCH_Num));
+  memSet (nghbtax, ~0, *nparts * sizeof (SCOTCH_Num));
+  nghbtax -= baseval;                               /* Base part array since parts are based in MeTiS */
 
   parttax = part - baseval;
   vsizval = 1;                                      /* Assume no vertex communication sizes */
@@ -306,7 +307,7 @@ const double * const        kbalval)
     SCOTCH_Num          edgennd;
 
     partval = part[vertnum];
-    nghbtab[partval] = vertnum;                   /* Do not count local neighbors in communication volume */
+    nghbtax[partval] = vertnum;                   /* Do not count local neighbors in communication volume */
     if (vsize != NULL)
       vsizval = vsize[vertnum];
 
@@ -316,15 +317,15 @@ const double * const        kbalval)
 
       vertend = edgetax[edgenum];
       partend = parttax[vertend];
-      if (nghbtab[partend] != vertnum) {          /* If first neighbor in this part */
-        nghbtab[partend] = vertnum;               /* Set part as accounted for      */
+      if (nghbtax[partend] != vertnum) {          /* If first neighbor in this part */
+        nghbtax[partend] = vertnum;               /* Set part as accounted for      */
         commvol += vsizval;
       }
     }
   }
   *volume = commvol;
 
-  memFree (nghbtab);
+  memFree (nghbtax + baseval);                    /* Free un-based array */
 
   return (METIS_OK);
 }
@@ -352,8 +353,8 @@ SCOTCH_Num * const          part)
   double              kbalval;
 
   kbalval = 0.01;
-  vwgt2   = ((*wgtflag & 2) != 0) ? vwgt   : NULL;
-  adjwgt2 = ((*wgtflag & 1) != 0) ? adjwgt : NULL;
+  vwgt2   = ((wgtflag == NULL) || ((*wgtflag & 2) != 0)) ? vwgt   : NULL;
+  adjwgt2 = ((wgtflag == NULL) || ((*wgtflag & 1) != 0)) ? adjwgt : NULL;
 
   return (_SCOTCH_METIS_PartGraph (n, xadj, adjncy, vwgt2, adjwgt2,
                                    numflag, nparts, NULL, options, edgecut, part,
@@ -383,10 +384,10 @@ SCOTCH_Num * const          part)
   double              kbalval;
 
   kbalval = 0.01;
-  vwgt2   = ((*wgtflag & 2) != 0) ? vwgt   : NULL;
-  adjwgt2 = ((*wgtflag & 1) != 0) ? adjwgt : NULL;
+  vwgt2   = ((wgtflag == NULL) || ((*wgtflag & 2) != 0)) ? vwgt   : NULL;
+  adjwgt2 = ((wgtflag == NULL) || ((*wgtflag & 1) != 0)) ? adjwgt : NULL;
 
-  return (_SCOTCH_METIS_PartGraph (n, xadj, adjncy, vwgt, adjwgt,
+  return (_SCOTCH_METIS_PartGraph (n, xadj, adjncy, vwgt2, adjwgt2,
                                    numflag, nparts, NULL, options, edgecut, part,
                                    SCOTCH_STRATRECURSIVE, &kbalval));
 }
@@ -414,10 +415,10 @@ SCOTCH_Num * const          part)
   double              kbalval;
 
   kbalval = 0.01;
-  vsize2  = ((*wgtflag & 1) != 0) ? vsize : NULL;
-  vwgt2   = ((*wgtflag & 2) != 0) ? vwgt  : NULL;
+  vsize2  = ((wgtflag == NULL) || ((*wgtflag & 1) != 0)) ? vsize : NULL;
+  vwgt2   = ((wgtflag == NULL) || ((*wgtflag & 2) != 0)) ? vwgt  : NULL;
 
-  return (_SCOTCH_METIS_PartGraph_Volume (n, xadj, adjncy, vwgt, vsize,
+  return (_SCOTCH_METIS_PartGraph_Volume (n, xadj, adjncy, vwgt2, vsize2,
                                           numflag, nparts, NULL, options, volume, part,
                                           SCOTCH_STRATDEFAULT, &kbalval));
 }
@@ -468,7 +469,7 @@ const SCOTCH_Num * const    vsize,
 const SCOTCH_Num * const    adjwgt,
 const SCOTCH_Num * const    nparts,
 const SCOTCH_Num * const    tpwgts,
-const double * const        ubvec, 
+const double * const        ubvec,
 const SCOTCH_Num * const    options,
 SCOTCH_Num * const          objval,
 SCOTCH_Num * const          part)
@@ -595,7 +596,7 @@ const SCOTCH_Num * const    vsize,
 const SCOTCH_Num * const    adjwgt,
 const SCOTCH_Num * const    nparts,
 const SCOTCH_Num * const    tpwgts,
-const double * const        ubvec, 
+const double * const        ubvec,
 const SCOTCH_Num * const    options,
 SCOTCH_Num * const          objval,
 SCOTCH_Num * const          part)
