@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2014,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -52,6 +52,8 @@
 /**                                 to   : 02 jun 1997     **/
 /**                # Version 4.0  : from : 09 feb 2004     **/
 /**                                 to   : 09 feb 2004     **/
+/**                # Version 6.0  : from : 12 nov 2014     **/
+/**                                 to   : 16 apr 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -64,9 +66,9 @@
 #define C_FILENBR                   1             /* Number of files in list                */
 #define C_FILEARGNBR                1             /* Number of files which can be arguments */
 
-#define C_filenamearcout            C_fileTab[0].name /* Architecture output file name */
+#define C_filenamearcout            fileBlockName (C_fileTab, 0) /* Architecture output file name */
 
-#define C_filepntrarcout            C_fileTab[0].pntr /* Architecture output file */
+#define C_filepntrarcout            fileBlockFile (C_fileTab, 0) /* Architecture output file */
 
 /*
 **  The type and structure definitions.
@@ -83,7 +85,7 @@ typedef enum C_MethType_ {
 **  The function prototypes.
 */
 
-void                        C_termBipart        (ArchMesh2 *, ArchMesh2Dom *, unsigned int, unsigned int *, unsigned int *, int (*) ());
+void                        C_termBipart        (ArchMesh2 *, ArchMesh2Dom *, Anum, Anum *, Anum *, int (*) ());
 int                         C_methBipartOne     (const ArchMesh2 * const, const ArchMesh2Dom * const, ArchMesh2Dom * restrict const, ArchMesh2Dom * restrict const);
 
 /*
@@ -94,5 +96,4 @@ int                         C_methBipartOne     (const ArchMesh2 * const, const
 #define abs(a)                      (((a) >= 0) ? (a) : -(a))
 #endif /* abs */
 
-#define C_termDist(x0,y0,x1,y1)     ((unsigned int) (abs ((int) (x0) - (int) (x1)) + \
-                                                     abs ((int) (y0) - (int) (y1))))
+#define C_termDist(x0,y0,x1,y1)     (abs ((x0) - (x1)) + abs ((y0) - (y1)))
